Frendoz

# CSS

- Home
- Text demo
- Form demo
- Table demo
- Tiles demo

# Javascript

- Autocomplete
- List Actions
- Modal
- Color palette
- Ajax

# Generic form demo

Input Input .validate-error

Présentation de l'erreur

Input .validate-error .error-border

Présentation de l'erreur avec clignotement de la bordure

Input .validate-ok autoComplete in form exemple
Textarea Select List

# Generic fieldset in form

Checkboxes Checkbox in .flex-row Checkbox in .flex-row
Text Input in .flex-row
Radio Buttons Radio Radio